@@ -1,23 +1,30 @@
-#   ---------------------------------------------------------------------- copyright and license ---
+#   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #
 #   file: lib/Test/Dist/Zilla.pm
 #
-#   Copyright © 2015, 2016 Van de Bugger.
-#
-#   This file is part of perl-Test-Dist-Zilla.
-#
-#   perl-Test-Dist-Zilla is free software: you can redistribute it and/or modify it under the terms
-#   of the GNU General Public License as published by the Free Software Foundation, either version
-#   3 of the License, or (at your option) any later version.
-#
-#   perl-Test-Dist-Zilla is distributed in the hope that it will be useful, but WITHOUT ANY
-#   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-#   PURPOSE. See the GNU General Public License for more details.
-#
-#   You should have received a copy of the GNU General Public License along with
-#   perl-Test-Dist-Zilla. If not, see <http://www.gnu.org/licenses/>.
-#
-#   ---------------------------------------------------------------------- copyright and license ---
+
+#pod =encoding UTF-8
+#pod
+#pod =head1 COPYRIGHT AND LICENSE
+#pod
+#pod Copyright © 2015 Van de Bugger
+#pod
+#pod This file is part of perl-Test-Dist-Zilla.
+#pod
+#pod perl-Test-Dist-Zilla is free software: you can redistribute it and/or modify it under the terms
+#pod of the GNU General Public License as published by the Free Software Foundation, either version
+#pod 3 of the License, or (at your option) any later version.
+#pod
+#pod perl-Test-Dist-Zilla is distributed in the hope that it will be useful, but WITHOUT ANY
+#pod WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+#pod PURPOSE. See the GNU General Public License for more details.
+#pod
+#pod You should have received a copy of the GNU General Public License along with
+#pod perl-Test-Dist-Zilla. If not, see <http://www.gnu.org/licenses/>.
+#pod
+#pod =cut
+
+#   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 #pod =head1 SYNOPSIS
 #pod
@@ -25,15 +32,18 @@
 #pod
 #pod     use namespace::autoclean;
 #pod     use Test::Routine;
-#pod     use Test::Deep qw{ cmp_deeply };
-#pod
 #pod     with 'Test::Dist::Zilla';
+#pod     use Test::Deep qw{ cmp_deeply };
 #pod
 #pod     test 'Build' => sub {
 #pod         my ( $self ) = @_;
 #pod         my $expected = $self->expected;
 #pod         $self->build();
-#pod         cmp_deeply( $self->exception, $expected->{ exception } );
+#pod         if ( exists( $expected->{ exception } ) ) {
+#pod             cmp_deeply( $self->exception, $expected->{ exception } );
+#pod         } else {
+#pod             is( $self->exception, undef );
+#pod         };
 #pod         if ( exists( $expected->{ messages } ) ) {
 #pod             cmp_deeply( $self->messages, $expected->{ messages } );
 #pod         };
@@ -56,74 +66,34 @@
 
 package Test::Dist::Zilla;
 
-use namespace::autoclean;
 use strict;
-use utf8;
-use version 0.77;
 use warnings;
+use namespace::autoclean;
+use utf8;
 
 # ABSTRACT: Test your Dist::Zilla plugin
-our $VERSION = 'v0.4.4'; # VERSION
+our $VERSION = '0.001'; # VERSION
 
-use Dist::Zilla::Tester::DieHard v0.6.0;    # `Survivor` should have `tempdir_obj` attribute.
+use Dist::Zilla::Tester::DieHard;
 use File::Temp qw{ tempdir };
 use Test::DZil qw{ dist_ini };
 use Test::More;
 use Test::Routine;
 use Try::Tiny;
 
-## REQUIRE: Software::License::Perl_5
-## REQUIRE: Moose 2.0800
+# `AutoPrereqs` hints:
+use Software::License::Perl_5   ();
+use Moose 2.0800                ();
     # ^ Test will likely fail with older Moose.
     #   Starting from 2.0800 "Roles can now override methods from other roles…".
 
 # --------------------------------------------------------------------------------------------------
 
-#pod =variable $Cleanup
-#pod
-#pod C<Dist::Zilla::Tester> creates distribution source and build directories in a temporary directory,
-#pod and then unconditionally cleans it up. Sometimes (especially in case of test failure) such behavior
-#pod may be not desirable — you may want to look at source or built files for troubleshooting purposes.
-#pod
-#pod C<Test::Dist::Zilla> provides control over temporary directory via C<$Test::Dist::Zilla::Cleanup>
-#pod package variable:
-#pod
-#pod =over
-#pod
-#pod =item C<0>
-#pod
-#pod Never clean up temporary directory.
-#pod
-#pod =item C<1>
-#pod
-#pod Clean up temporary directory only if the test is passed (it is default).
-#pod
-#pod =item C<2>
-#pod
-#pod Always clean up temporary directory.
-#pod
-#pod =back
-#pod
-#pod If temporary directory is going to remain, the test output will contain diagnostic message like
-#pod this one:
-#pod
-#pod     # tempdir: tmp/AKrvBhhM4M
-#pod
-#pod to help you identify the temporary directory created for the test.
-#pod
-#pod Note: Controlling temporary directory requires C<Dist::Zilla> 5.021 or newer.
-#pod
-#pod =cut
-
-our $Cleanup = 1;                       ## no critic ( ProhibitPackageVars )
-
-# --------------------------------------------------------------------------------------------------
-
 #pod =attr C<dist>
 #pod
 #pod Hash of distribution options: C<name>, C<version> C<abstract>, etc. to write to the test's
 #pod F<dist.ini>. This attribute is passed to C<dist_ini> as C<\%root_config> argument, see
-#pod L<Test::DZil/"dist_ini">.
+#pod L<Test::DZill/"dist_ini">.
 #pod
 #pod C<HashRef>. Default value can be overridden by defining C<_build_dist> builder.
 #pod
@@ -133,17 +103,17 @@ our $Cleanup = 1;                       ## no critic ( ProhibitPackageVars )
 #pod         name     => 'Assa',
 #pod         version  => '0.007',
 #pod         author   => 'John Doe',
-#pod         ...
+#pod         …
 #pod     } };
 #pod
 #pod     run_me {
 #pod         dist => {
-#pod             name     => 'Shooba',
-#pod             version  => 'v0.7.0',
-#pod             author   => 'John Doe, Jr.',
-#pod             ...
+#pod             name     => 'Assa',
+#pod             version  => '0.007',
+#pod             author   => 'John Doe',
+#pod             …
 #pod         },
-#pod         ...
+#pod         …
 #pod     };
 #pod
 #pod TODO: Merge specified keys into default?
@@ -174,7 +144,7 @@ sub _build_dist {
 #pod =attr C<plugins>
 #pod
 #pod Plugin configuration to write to the test's F<dist.ini>. Attribute is passed to C<dist_ini> as
-#pod C<@plugins> argument, see L<Test::DZil/"dist_ini">.
+#pod C<@plugins> argument, see L<Test::DZill/"dist_ini">.
 #pod
 #pod C<ArrayRef>, optional. Default value is empty array (i. e. no plugins), it can be overridden by
 #pod defining C<_build_plugins> builder.
@@ -194,7 +164,7 @@ sub _build_dist {
 #pod                 'replacer' => 'replace_with_comment',
 #pod             } ],
 #pod         ],
-#pod         ...
+#pod         …
 #pod     };
 #pod
 #pod =cut
@@ -218,7 +188,8 @@ sub _build_plugins {
 #pod contents. A file content may be specified by a (possibly multi-line) string or by array of lines
 #pod (newlines are optional and will be appended if missed).
 #pod
-#pod Note: Explicitly specified F<dist.ini> file overrides C<dist> and C<plugins> attributes.
+#pod Note: Do not specify F<dist.ini> file in C<files> — F<dist.ini> is generated from C<dist> and
+#pod C<plugins> attributes.
 #pod
 #pod C<HashRef>, optional, default value is empty hash (i. e. no files).
 #pod
@@ -231,15 +202,15 @@ sub _build_plugins {
 #pod             '1;',
 #pod         ],
 #pod         'Changes'  => "Release history for Dist-Zilla-Plugin-Assa\n\n",
-#pod         'MANIFEST' => [ qw{ lib/Assa.pm Changes MANIFEST } ],
+#pod         'MANIFEST' => "lib/Assa.pm\nChanges\nMANIFEST\n",
 #pod     } };
 #pod
 #pod     run_me {
 #pod         files => {
-#pod             'lib/Assa.pod' => [ ... ],
-#pod             ...
+#pod             'lib/Assa.pod' => [ … ],
+#pod             …
 #pod         },
-#pod         ...
+#pod         …
 #pod     };
 #pod
 #pod =cut
@@ -262,30 +233,30 @@ sub _build_files {
 #pod Test-enabled C<Dist::Zilla> instance (or C<DieHard> "survivor" object, if C<Dist::Zilla>
 #pod constructing fails).
 #pod
-#pod By default C<Dist::Zilla> instance is created by calling C<< Builder->from_config( ... ) >> with
+#pod By default C<Dist::Zilla> instance is created by calling C<< Builder->from_config( … ) >> with
 #pod appropriate arguments. Thanks to C<Dist::Zilla::Tester::DieHard>, it is never dies even if
-#pod constructing fails, so C<< $self->tzil->log_message >> returns the log messages anyway.
+#pod constructing fails, so C<< $self->tzil->log_message >> returns the log messages in anyway.
 #pod
-#pod Note: Avoid calling C<build> and C<release> on C<tzil>:
+#pod Note: Avoid calling C<build> on C<tzil>:
 #pod
-#pod     $self->tzil->build();       # NOT recommended
-#pod     $self->tzil->release();     # NOT recommended
+#pod     $self->tzil->build();
 #pod
-#pod Call C<build> and C<release> directly on C<$self> instead:
+#pod Call C<build> directly on C<$self> instead:
 #pod
-#pod     $self->build();             # recommended
-#pod     $self->release();           # recommended
+#pod     $self->build();
 #pod
-#pod See C<build> and C<release> method descriptions for difference.
+#pod See C<build> method description for difference.
 #pod
 #pod Examples:
 #pod
 #pod     use Path::Tiny;
-#pod     test 'Check META.json' => sub {
+#pod     tests 'Check META.json' => sub {
 #pod         my ( $self ) = @_;
-#pod         $self->skip_if_exception();
+#pod         if ( $self->exception ) {
+#pod             plan skip_all => 'exception occurred';
+#pod         };
 #pod         my $built_in = path( $self->tzil->built_in );
-#pod         my $json = $built_in->child( 'META.json' )->slurp_utf8;
+#pod         my $json = $built_in->child( 'META.json' )->slurp;
 #pod         cmp_deeply( $json, $self->expected->{ json } );
 #pod     };
 #pod
@@ -297,20 +268,14 @@ has tzil => (
     lazy        => 1,
     builder     => '_build_tzil',
     init_arg    => undef,
-    handles     => [ qw{ build release } ],
+    handles     => [ qw{ build } ],
 );
 
 sub _build_tzil {
     my ( $self ) = @_;
     my $files = $self->files;
-    my $tzil = Builder->from_config(
-        {
-            dist_root => tempdir( CLEANUP => 1 ),
-                #   `Dist::Zilla::Tester::_Builder` copies all the files from `dist_root` directory
-                #   to the source directory. We do not have any prepared files, but have to specify
-                #   `dist_root` option because `Dist::Zilla::Tester::_Builder` requires it. Let us
-                #   specify a temporary empty directory.
-        },
+    return Builder->from_config(
+        { dist_root => tempdir( CLEANUP => 1 ) },
         {
             add_files => {
                 'source/dist.ini' => dist_ini(
@@ -319,56 +284,46 @@ sub _build_tzil {
                 ),
                 map(
                     { (
-                        "source/$_" =>
-                            ref ( $files->{ $_ } ) ? (
-                                join(
-                                    '',
-                                    map(
-                                        { ( my $r = $_ ) =~ s{(?<!\n)\z}{\n}x; $r }
-                                        @{ $files->{ $_ } }
-                                    )
+                        "source/$_" => ref ( $files->{ $_ } ) ? (
+                            join(
+                                '',
+                                map(
+                                    { ( my $r = $_ ) =~ s{(?<!\n)\z}{\n}x; $r }
+                                    @{ $files->{ $_ } }
                                 )
-                            ) : (
-                                $files->{ $_ }
                             )
+                        ) : (
+                            $files->{ $_ }
+                        )
                     ) }
                     keys( %$files ),
                 ),
             },
         },
     );
-    return $tzil;
 };
 
 # --------------------------------------------------------------------------------------------------
 
 #pod =method C<build>
 #pod
-#pod =method C<release>
+#pod The method calls same-name method on C<tzil>, catches exception if any thrown, and saves the caught
+#pod exception in C<exception> attribute for further analysis.
 #pod
-#pod The methods call same-name method on C<tzil>, catch exception if any thrown, and save the caught
-#pod exception in the C<exception> attribute for further analysis.
-#pod
-#pod Avoid calling these methods on C<tzil> — some tests may rely on method modifiers, which are
-#pod applicable to C<< $self->I<method>() >> but not to C<< $self->tzil->I<method>() >>.
+#pod Avoid calling C<build> on C<tzil> — some tests may rely on C<build> method modifiers, which are
+#pod applicable to C<< $self->build() >> but not to C<< $self->tzil->build() >>.
 #pod
 #pod Examples:
 #pod
-#pod     test Build => sub {
+#pod     test 'Build' => sub {
 #pod         my ( $self ) = @_;
-#pod         $self->build();     # == dzil build
-#pod         ...
-#pod     };
-#pod
-#pod     test Release => sub {
-#pod         my ( $self ) = @_;
-#pod         $self->release();   # == dzil release
-#pod         ...
+#pod         $self->build();
+#pod         …
 #pod     };
 #pod
 #pod =cut
 
-around [ qw{ build release } ] => sub {
+around build => sub {
     my ( $orig, $self, @args ) = @_;
     my $ret;
     try {
@@ -383,12 +338,14 @@ around [ qw{ build release } ] => sub {
 
 #pod =attr C<exception>
 #pod
-#pod Exception occurred, or C<undef> is no exception was occurred.
+#pod Exception occurred during build, or C<undef> is no exception were occurred.
 #pod
 #pod     test 'Post-build' => sub {
 #pod         my ( $self ) = @_;
-#pod         cmp_deeply( $self->exception, $self->expected->{ exception } );
-#pod         ...
+#pod         if ( $self->exception ) {
+#pod             plan skip_all => 'exception thrown';
+#pod         };
+#pod         …
 #pod     };
 #pod
 #pod =cut
@@ -403,16 +360,15 @@ has exception => (
 
 #pod =attr C<expected>
 #pod
-#pod A hash of expected outcomes. C<Test::Dist::Zilla> itself does not use this attribute, but more
-#pod specific roles may do. For example, C<Test::Dizt::Zilla::Build> uses C<exception> and C<messages>
-#pod keys, C<Test::Dizt::Zilla::BuiltFiles> uses C<files> key.
+#pod A hash of expected outcomes. C<Test::Dist::Zilla> itself does use this attribute, but more specific
+#pod roles may do. For example, C<Test::Dizt::Zilla::Build> uses C<exception> and C<messages> keys.
 #pod
 #pod C<HashRef>, required.
 #pod
 #pod Examples:
 #pod
 #pod     run_me {
-#pod         ...,
+#pod         …,
 #pod         expected => {
 #pod             exception => "Aborting...\n",
 #pod             messages  => [
@@ -459,11 +415,11 @@ sub messages {
 
 #pod =attr C<message_filter>
 #pod
-#pod If C<message_filter> is defined, it is used by default C<messages> implementation to filter the
+#pod If C<message_filter> is defined, it is used by the default C<messages> implementation to filter the
 #pod actual log messages. C<message_filter> function is called once with list of all the log messages.
 #pod The function is expected to return a list of messages (possibly, grepped and/or edited).
 #pod
-#pod Note: C<message_filter> value is a function, not method — C<messages> method does not pass C<$self>
+#pod Note: C<message_filter> is a function, not method — C<messages> method does not pass C<$self>
 #pod reference to the C<message_filter>.
 #pod
 #pod If C<messages> method is overridden, the attribute may be used or ignored — it depends on new
@@ -485,7 +441,7 @@ sub messages {
 #pod
 #pod     run_me {
 #pod         message_filter => sub { map( { $_ =~ s{^\[.*?\] }{}r ) @_ ) },
-#pod         ...
+#pod         …
 #pod     };
 #pod
 #pod =cut
@@ -503,32 +459,6 @@ sub _build_message_filter {
 
 # --------------------------------------------------------------------------------------------------
 
-#pod =method skip_if_exception
-#pod
-#pod This convenience method makes test routines a bit shorter. Instead of writing
-#pod
-#pod     if ( defined( $self->exception ) ) {
-#pod         plan skip_all => 'exception occurred';
-#pod     };
-#pod
-#pod you can write just
-#pod
-#pod     $self->skip_if_exception;
-#pod
-#pod =cut
-
-sub skip_if_exception {
-    my ( $self ) = @_;
-    if ( defined( $self->exception ) ) {
-        plan skip_all => 'exception occurred';
-    };
-    return;
-};
-
-# --------------------------------------------------------------------------------------------------
-
-# This stuff is not settled down yet.
-
 has _annotation => (
     is      => 'ro',
     isa     => 'Str',
@@ -537,39 +467,12 @@ has _annotation => (
 
 after run_test => sub {
     my ( $self ) = @_;
-    require Test::Builder;
     my $tb = Test::Builder->new();
     if ( not $tb->is_passing and $self->_annotation ne '' ) {
-        ( my $annotation = $self->_annotation ) =~ s{^}{| }gmx;
+        ( my $annotation = $self->_annotation ) =~ s{^}{│ }gmx;
         $tb->diag( $annotation );
         $self->{ _annotation } = '';
     };
-    # Manage temporary directory:
-    if ( $Cleanup < 2 ) {
-        if ( $self->tzil->can( 'tempdir_obj' ) ) {
-            if ( my $tempdir = $self->tzil->tempdir_obj ) {
-                # `tzil` could be `Survivor` which does not have temp dir (`tempdir_obj` returns
-                # `undef`).
-                my $cleanup = $Cleanup;
-                if ( $cleanup == 1 ) {
-                    $cleanup = $tb->is_passing;
-                };
-                if ( not $cleanup ) {
-                    diag( "tempdir: $tempdir" );
-                    $tempdir->unlink_on_destroy( $cleanup );
-                };
-            };
-        } else {
-            require Dist::Zilla;
-            diag(
-                "You are running Dist::Zilla $Dist::Zilla::VERSION. Temporary directory will be " .
-                "unconditionally cleaned up, because Test::Zilla::Tester::_Builder does not have " .
-                "tempdir_obj attribute. " .
-                "(tempdir_obj attribute appeared in Dist::Zilla::Tester::_Builder 5.021.)"
-            );
-            $Cleanup = 2;   # Avoid printing the message again and again.
-        };
-    };
 };
 
 # --------------------------------------------------------------------------------------------------
@@ -609,24 +512,11 @@ sub _anno_text {
 #pod
 #pod =for :list
 #pod = L<Test::Dist::Zilla::Build>
-#pod = L<Test::Dist::Zilla::BuiltFiles>
-#pod = L<Test::Dist::Zilla::Release>
 #pod = L<Test::Routine>
 #pod = L<Dist::Zilla>
 #pod = L<Dist::Zilla::Tester::DieHard>
 #pod = L<Test::DZil/"dist_ini">
 #pod
-#pod =head1 COPYRIGHT AND LICENSE
-#pod
-#pod Copyright (C) 2015, 2016 Van de Bugger
-#pod
-#pod License GPLv3+: The GNU General Public License version 3 or later
-#pod <http://www.gnu.org/licenses/gpl-3.0.txt>.
-#pod
-#pod This is free software: you are free to change and redistribute it. There is
-#pod NO WARRANTY, to the extent permitted by law.
-#pod
-#pod
 #pod =cut
 
 # end of file #
@@ -643,7 +533,7 @@ Test::Dist::Zilla - Test your Dist::Zilla plugin
 
 =head1 VERSION
 
-Version v0.4.4, released on 2016-12-28 19:48 UTC.
+Version 0.001, released on 2015-08-23 23:03 UTC.
 
 =head1 SYNOPSIS
 
@@ -651,15 +541,18 @@ Version v0.4.4, released on 2016-12-28 19:48 UTC.
 
     use namespace::autoclean;
     use Test::Routine;
-    use Test::Deep qw{ cmp_deeply };
-
     with 'Test::Dist::Zilla';
+    use Test::Deep qw{ cmp_deeply };
 
     test 'Build' => sub {
         my ( $self ) = @_;
         my $expected = $self->expected;
         $self->build();
-        cmp_deeply( $self->exception, $expected->{ exception } );
+        if ( exists( $expected->{ exception } ) ) {
+            cmp_deeply( $self->exception, $expected->{ exception } );
+        } else {
+            is( $self->exception, undef );
+        };
         if ( exists( $expected->{ messages } ) ) {
             cmp_deeply( $self->messages, $expected->{ messages } );
         };
@@ -684,7 +577,7 @@ specific roles, for example, C<Test::Dist::Zilla::Build>.
 
 Hash of distribution options: C<name>, C<version> C<abstract>, etc. to write to the test's
 F<dist.ini>. This attribute is passed to C<dist_ini> as C<\%root_config> argument, see
-L<Test::DZil/"dist_ini">.
+L<Test::DZill/"dist_ini">.
 
 C<HashRef>. Default value can be overridden by defining C<_build_dist> builder.
 
@@ -694,17 +587,17 @@ Examples:
         name     => 'Assa',
         version  => '0.007',
         author   => 'John Doe',
-        ...
+        …
     } };
 
     run_me {
         dist => {
-            name     => 'Shooba',
-            version  => 'v0.7.0',
-            author   => 'John Doe, Jr.',
-            ...
+            name     => 'Assa',
+            version  => '0.007',
+            author   => 'John Doe',
+            …
         },
-        ...
+        …
     };
 
 TODO: Merge specified keys into default?
@@ -712,7 +605,7 @@ TODO: Merge specified keys into default?
 =head2 C<plugins>
 
 Plugin configuration to write to the test's F<dist.ini>. Attribute is passed to C<dist_ini> as
-C<@plugins> argument, see L<Test::DZil/"dist_ini">.
+C<@plugins> argument, see L<Test::DZill/"dist_ini">.
 
 C<ArrayRef>, optional. Default value is empty array (i. e. no plugins), it can be overridden by
 defining C<_build_plugins> builder.
@@ -732,7 +625,7 @@ Examples:
                 'replacer' => 'replace_with_comment',
             } ],
         ],
-        ...
+        …
     };
 
 =head2 C<files>
@@ -741,7 +634,8 @@ Hash of source files to add to the test's distribution source. Keys are file nam
 contents. A file content may be specified by a (possibly multi-line) string or by array of lines
 (newlines are optional and will be appended if missed).
 
-Note: Explicitly specified F<dist.ini> file overrides C<dist> and C<plugins> attributes.
+Note: Do not specify F<dist.ini> file in C<files> — F<dist.ini> is generated from C<dist> and
+C<plugins> attributes.
 
 C<HashRef>, optional, default value is empty hash (i. e. no files).
 
@@ -754,15 +648,15 @@ Examples:
             '1;',
         ],
         'Changes'  => "Release history for Dist-Zilla-Plugin-Assa\n\n",
-        'MANIFEST' => [ qw{ lib/Assa.pm Changes MANIFEST } ],
+        'MANIFEST' => "lib/Assa.pm\nChanges\nMANIFEST\n",
     } };
 
     run_me {
         files => {
-            'lib/Assa.pod' => [ ... ],
-            ...
+            'lib/Assa.pod' => [ … ],
+            …
         },
-        ...
+        …
     };
 
 =head2 C<tzil>
@@ -770,55 +664,56 @@ Examples:
 Test-enabled C<Dist::Zilla> instance (or C<DieHard> "survivor" object, if C<Dist::Zilla>
 constructing fails).
 
-By default C<Dist::Zilla> instance is created by calling C<< Builder->from_config( ... ) >> with
+By default C<Dist::Zilla> instance is created by calling C<< Builder->from_config( … ) >> with
 appropriate arguments. Thanks to C<Dist::Zilla::Tester::DieHard>, it is never dies even if
-constructing fails, so C<< $self->tzil->log_message >> returns the log messages anyway.
+constructing fails, so C<< $self->tzil->log_message >> returns the log messages in anyway.
 
-Note: Avoid calling C<build> and C<release> on C<tzil>:
+Note: Avoid calling C<build> on C<tzil>:
 
-    $self->tzil->build();       # NOT recommended
-    $self->tzil->release();     # NOT recommended
+    $self->tzil->build();
 
-Call C<build> and C<release> directly on C<$self> instead:
+Call C<build> directly on C<$self> instead:
 
-    $self->build();             # recommended
-    $self->release();           # recommended
+    $self->build();
 
-See C<build> and C<release> method descriptions for difference.
+See C<build> method description for difference.
 
 Examples:
 
     use Path::Tiny;
-    test 'Check META.json' => sub {
+    tests 'Check META.json' => sub {
         my ( $self ) = @_;
-        $self->skip_if_exception();
+        if ( $self->exception ) {
+            plan skip_all => 'exception occurred';
+        };
         my $built_in = path( $self->tzil->built_in );
-        my $json = $built_in->child( 'META.json' )->slurp_utf8;
+        my $json = $built_in->child( 'META.json' )->slurp;
         cmp_deeply( $json, $self->expected->{ json } );
     };
 
 =head2 C<exception>
 
-Exception occurred, or C<undef> is no exception was occurred.
+Exception occurred during build, or C<undef> is no exception were occurred.
 
     test 'Post-build' => sub {
         my ( $self ) = @_;
-        cmp_deeply( $self->exception, $self->expected->{ exception } );
-        ...
+        if ( $self->exception ) {
+            plan skip_all => 'exception thrown';
+        };
+        …
     };
 
 =head2 C<expected>
 
-A hash of expected outcomes. C<Test::Dist::Zilla> itself does not use this attribute, but more
-specific roles may do. For example, C<Test::Dizt::Zilla::Build> uses C<exception> and C<messages>
-keys, C<Test::Dizt::Zilla::BuiltFiles> uses C<files> key.
+A hash of expected outcomes. C<Test::Dist::Zilla> itself does use this attribute, but more specific
+roles may do. For example, C<Test::Dizt::Zilla::Build> uses C<exception> and C<messages> keys.
 
 C<HashRef>, required.
 
 Examples:
 
     run_me {
-        ...,
+        …,
         expected => {
             exception => "Aborting...\n",
             messages  => [
@@ -829,11 +724,11 @@ Examples:
 
 =head2 C<message_filter>
 
-If C<message_filter> is defined, it is used by default C<messages> implementation to filter the
+If C<message_filter> is defined, it is used by the default C<messages> implementation to filter the
 actual log messages. C<message_filter> function is called once with list of all the log messages.
 The function is expected to return a list of messages (possibly, grepped and/or edited).
 
-Note: C<message_filter> value is a function, not method — C<messages> method does not pass C<$self>
+Note: C<message_filter> is a function, not method — C<messages> method does not pass C<$self>
 reference to the C<message_filter>.
 
 If C<messages> method is overridden, the attribute may be used or ignored — it depends on new
@@ -855,33 +750,25 @@ Drop plugin names from messages:
 
     run_me {
         message_filter => sub { map( { $_ =~ s{^\[.*?\] }{}r ) @_ ) },
-        ...
+        …
     };
 
 =head1 OBJECT METHODS
 
 =head2 C<build>
 
-=head2 C<release>
+The method calls same-name method on C<tzil>, catches exception if any thrown, and saves the caught
+exception in C<exception> attribute for further analysis.
 
-The methods call same-name method on C<tzil>, catch exception if any thrown, and save the caught
-exception in the C<exception> attribute for further analysis.
-
-Avoid calling these methods on C<tzil> — some tests may rely on method modifiers, which are
-applicable to C<< $self->I<method>() >> but not to C<< $self->tzil->I<method>() >>.
+Avoid calling C<build> on C<tzil> — some tests may rely on C<build> method modifiers, which are
+applicable to C<< $self->build() >> but not to C<< $self->tzil->build() >>.
 
 Examples:
 
-    test Build => sub {
+    test 'Build' => sub {
         my ( $self ) = @_;
-        $self->build();     # == dzil build
-        ...
-    };
-
-    test Release => sub {
-        my ( $self ) = @_;
-        $self->release();   # == dzil release
-        ...
+        $self->build();
+        …
     };
 
 =head2 C<messages>
@@ -897,64 +784,12 @@ Examples:
 
     cmp_deeply( $self->messages, $self->expected->{ messages } );
 
-=head2 skip_if_exception
-
-This convenience method makes test routines a bit shorter. Instead of writing
-
-    if ( defined( $self->exception ) ) {
-        plan skip_all => 'exception occurred';
-    };
-
-you can write just
-
-    $self->skip_if_exception;
-
-=head1 VARIABLES
-
-=head2 $Cleanup
-
-C<Dist::Zilla::Tester> creates distribution source and build directories in a temporary directory,
-and then unconditionally cleans it up. Sometimes (especially in case of test failure) such behavior
-may be not desirable — you may want to look at source or built files for troubleshooting purposes.
-
-C<Test::Dist::Zilla> provides control over temporary directory via C<$Test::Dist::Zilla::Cleanup>
-package variable:
-
-=over
-
-=item C<0>
-
-Never clean up temporary directory.
-
-=item C<1>
-
-Clean up temporary directory only if the test is passed (it is default).
-
-=item C<2>
-
-Always clean up temporary directory.
-
-=back
-
-If temporary directory is going to remain, the test output will contain diagnostic message like
-this one:
-
-    # tempdir: tmp/AKrvBhhM4M
-
-to help you identify the temporary directory created for the test.
-
-Note: Controlling temporary directory requires C<Dist::Zilla> 5.021 or newer.
-
 =head1 SEE ALSO
 
 =over 4
 
 =item L<Test::Dist::Zilla::Build>
 
-=item L<Test::Dist::Zilla::BuiltFiles>
-
-=item L<Test::Dist::Zilla::Release>
-
 =item L<Test::Routine>
 
 =item L<Dist::Zilla>
@@ -971,12 +806,19 @@ Van de Bugger <van.de.bugger@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015, 2016 Van de Bugger
+Copyright © 2015 Van de Bugger
 
-License GPLv3+: The GNU General Public License version 3 or later
-<http://www.gnu.org/licenses/gpl-3.0.txt>.
+This file is part of perl-Test-Dist-Zilla.
 
-This is free software: you are free to change and redistribute it. There is
-NO WARRANTY, to the extent permitted by law.
+perl-Test-Dist-Zilla is free software: you can redistribute it and/or modify it under the terms
+of the GNU General Public License as published by the Free Software Foundation, either version
+3 of the License, or (at your option) any later version.
+
+perl-Test-Dist-Zilla is distributed in the hope that it will be useful, but WITHOUT ANY
+WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+PURPOSE. See the GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License along with
+perl-Test-Dist-Zilla. If not, see <http://www.gnu.org/licenses/>.
 
 =cut
